==> nextcloud-28.0.3.tgz: nextcloud/apps/user_status/l10n/sk.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Nedávne stavy",
    "No recent status changes" : "Žiadne nedávne zmeny stavu",
    "In a meeting" : "Na schôdzke",
    "Commuting" : "Na ceste",
    "Out sick" : "Choroba",
    "Vacationing" : "Na dovolenke",
    "Out of office" : "Mimo kancelárie",
    "Working remotely" : "Pracujem na diaľku",
    "In a call" : "práve telefonuje",
    "User status" : "Stav užívateľa",
    "Clear status after" : "Vyčistiť správu o stave po",
    "What is your status?" : "Aký je váš stav?",
    "Set status" : "Nastaviť stav",
    "Online status" : "Stav pripojenia",
    "Status message" : "Správa o stave",
    "Clear status message" : "Vyčistiť správu o stave",
    "Set status message" : "Nastaviť správu o stave",
    "There was an error saving the status" : "Pri ukladaní stavu sa vyskytla chyba",
    "There was an error clearing the status" : "Pri čistení stavu sa vyskytla chyba",
    "Don't clear" : "Nemazať",
    "Today" : "Dnes",
    "This week" : "Tento týždeň",
    "Online" : "Pripojené",
    "Away" : "Preč",
    "Do not disturb" : "Nerušiť",
    "Invisible" : "Neviditeľnosť",
    "Offline" : "Offline",
    "There was an error saving the new status" : "Pri ukladaní nového stavu sa vyskytla chyba",
    "30 minutes" : "30 minút",
    "1 hour" : "1 hodina",
    "4 hours" : "4 hodiny",
    "Mute all notifications" : "Stíšiť všetky upozornenia",
    "Appear offline" : "V odpojenom režime",
    "View profile" : "Zobraziť profil",
    "{status}, {timestamp}" : "{status}, {timestamp}"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-28.0.7.tgz: nextcloud/apps/user_status/l10n/sk.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Nedávne stavy",
    "No recent status changes" : "Žiadne nedávne zmeny stavu",
    "In a meeting" : "Na schôdzke",
    "Commuting" : "Na ceste",
    "Out sick" : "Choroba",
    "Vacationing" : "Na dovolenke",
    "Out of office" : "Mimo kancelárie",
    "Working remotely" : "Pracujem na diaľku",
    "In a call" : "práve telefonuje",
    "User status" : "Stav užívateľa",
    "Clear status after" : "Vyčistiť správu o stave po",
    "Emoji for your status message" : "Emoji pre vašu statusovú správu",
    "What is your status?" : "Aký je váš stav?",
    "Predefined statuses" : "Preddefinované statusy",
    "Previously set" : "Predtým nastavené",
    "Reset status" : "Obnoviť status",
    "Set status" : "Nastaviť stav",
    "Online status" : "Stav pripojenia",
    "Status message" : "Správa o stave",
    "Your status was set automatically" : "Váš status bol nastavený automaticky",
    "Clear status message" : "Vyčistiť správu o stave",
    "Set status message" : "Nastaviť správu o stave",
    "Reset status to \"{icon} {message}\"" : "Obnoviť stav na „{icon} {message}“",
    "Reset status to \"{message}\"" : "Obnoviť stav na „{message}“",
    "Reset status to \"{icon}\"" : "Obnoviť stav na „{icon}“",
    "There was an error saving the status" : "Pri ukladaní stavu sa vyskytla chyba",
    "There was an error clearing the status" : "Pri čistení stavu sa vyskytla chyba",
    "There was an error reverting the status" : "Pri zmene statusu sa vyskytla chyba",
    "Don't clear" : "Nemazať",
    "Today" : "Dnes",
    "This week" : "Tento týždeň",
    "Online" : "Pripojené",
    "Away" : "Preč",
    "Do not disturb" : "Nerušiť",
    "Invisible" : "Neviditeľnosť",
    "Offline" : "Offline",
    "There was an error saving the new status" : "Pri ukladaní nového stavu sa vyskytla chyba",
    "30 minutes" : "30 minút",
    "1 hour" : "1 hodina",
    "4 hours" : "4 hodiny",
    "Mute all notifications" : "Stíšiť všetky upozornenia",
    "Appear offline" : "V odpojenom režime",
    "View profile" : "Zobraziť profil"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
